#!/bin/sh

. /etc.defaults/rc.subr

#synorcd=/usr/syno/sbin/synorcd
PACKAGE_DIR="/var/packages/AudioStation"
PACKAGE_TARGET_DIR="${PACKAGE_DIR}/target"
synoaudiod="${PACKAGE_TARGET_DIR}/sbin/synoaudiod"
pulseaudio="${PACKAGE_TARGET_DIR}/bin/pulseaudio"
AUDIO_CHECK_SUPPORT="${PACKAGE_TARGET_DIR}/pkgbin/audio_check_support"
CAT=/bin/cat
RENICE=/usr/bin/renice
SZF_AUDIOD_PID=/var/run/synoaudiod.pid
#dms_local="/usr/syno/sbin/dms.local --localserver"
KERNELMODULE="soundcore snd-page-alloc snd snd-seq-device snd-rawmidi snd-usbmidi-lib snd-usb-lib snd-hwdep snd-timer snd-pcm snd-usb-audio snd-mixer-oss snd-pcm-oss"
COMPATMODULE="snd-usb-hiface"

UPGRADE_SCRIPTS_DIR="${PACKAGE_TARGET_DIR}/scripts/upgrade/"
MTPLAYLIST="/etc/mt-daapd.playlist"

SYNOPSQL="/usr/syno/bin/synopsql"
DATABASE="mediaserver"
DB_USER="MediaIndex"

IsBlueToothSupport()
{
	${AUDIO_CHECK_SUPPORT} --support-bluetooth
	if [ "1" = "$?" ]; then
		true
		return
	fi
	false
}

IsUSBSupport()
{
	${AUDIO_CHECK_SUPPORT} --support-usb
	if [ "1" = "$?" ]; then
		true
		return
	fi
	false
}

CheckIfDaemonAlive()
{
	if [ -f "$1" ]; then
		local processPid=`cat $1`
		kill -0 ${processPid} > /dev/null 2>&1
		if [ "0" = "$?" ]; then
			true
			return
		fi
	fi
	false
}

change_owner() {
	echo "Change $DATABASE owner to $DB_USER"
	$SYNOPSQL --change-own "$DATABASE" "$DB_USER"
}

case $1 in
	start)
		NeedChangeOwn=0

		if [ ! -f "${MTPLAYLIST}" ]; then
			touch ${MTPLAYLIST}
		fi

		upgrades=`find $UPGRADE_SCRIPTS_DIR -name "*.sh" | sort`
		for ThisArg in $upgrades;
		do
			$ThisArg
			Ret=$?
			if [ $Ret = 1 ]; then
				NeedChangeOwn=1
			fi
		done

		if [ $NeedChangeOwn = 1 ]; then
			# run change owner to ensure owner of db, tables, sequences, views are DB_USER
			change_owner
		fi

		if CheckIfDaemonAlive "$SZF_AUDIOD_PID"; then
			echo "Daemon synoaudiod exist. Skip start action."
		else
			echo "Starting synoaudiod ..."
			if IsUSBSupport; then
				SYNOLoadModules $KERNELMODULE
				SYNOLoadModules $COMPATMODULE
			fi
			$synoaudiod

			if IsBlueToothSupport; then
				echo "Starting pulseaudio"
				$pulseaudio --realtime=false
			fi

			# renice audiod to higher priority
			sleep 1
			$RENICE -5 `$CAT $SZF_AUDIOD_PID`
		fi
	;;
	stop)
		echo "Stopping synoaudiod ..."
		/usr/bin/killall synoaudiod > /dev/null 2>&1
		sleep 1
		/usr/bin/killall -9 synoaudiod > /dev/null 2>&1
		if IsUSBSupport; then
			SYNOUnloadModules $COMPATMODULE
			SYNOUnloadModules $KERNELMODULE
		fi
		rm -f $SZF_AUDIOD_PID

		if IsBlueToothSupport; then
			echo "Stopping pulseaudio"
			/usr/bin/killall pulseaudio > /dev/null 2>&1
		fi
	;;
	restart)
		$0 stop
		sleep 1
		$0 start
	;;
	restart-audiod)
		echo "restart synoaudiod"

		##  stop synoaudiod
		/usr/bin/killall synoaudiod > /dev/null 2>&1
		sleep 1
		/usr/bin/killall -9 synoaudiod > /dev/null 2>&1
		rm -f $SZF_AUDIOD_PID

		sleep 1

		##  start synoaudiod
		if CheckIfDaemonAlive "$SZF_AUDIOD_PID"; then
			echo "Daemon synoaudiod exist. Skip start action."
		else
			$synoaudiod

			# renice audiod to higher priority
			sleep 1
			$RENICE -5 `$CAT $SZF_AUDIOD_PID`
		fi
	;;
	*)
		echo "Usage: $0 start|stop|restart"
	;;
esac

